Borrowing-class: 'Borrowing' Class

Borrowing-classR Documentation

Borrowing Class

Description

A class for defining borrowing details. Objects of class Borrowing should not be created directly but by the constructors borrowing_hierarchical_commensurate(), borrowing_none(), borrowing_full().

Slots

method_name

string. The name of the method.

ext_flag_col

character. Name of the external flag column in the matrix.

See Also

Prior constructor functions: borrowing_full(), borrowing_hierarchical_commensurate(), borrowing_none()

Other borrowing classes: BorrowingFixedPowerPrior-class, BorrowingFull-class, BorrowingHierarchicalCommensurate-class, BorrowingNone-class


psborrow2 documentation built on May 14, 2026, 5:10 p.m.