BorrowingFixedPowerPrior-class: 'BorrowingFixedPowerPrior' class

BorrowingFixedPowerPrior-classR Documentation

BorrowingFixedPowerPrior class

Description

BorrowingFixedPowerPrior class

Slots

method_name

string. The name of the method.

ext_flag_col

character. Name of the external flag column in the matrix.

powers

numeric. The fixed values to be used as the powers in the power prior.

See Also

Other borrowing classes: Borrowing-class, BorrowingFull-class, BorrowingHierarchicalCommensurate-class, BorrowingNone-class


psborrow2 documentation built on May 14, 2026, 5:10 p.m.