SimTreatmentList-class: 'SimTreatmentList' Class

SimTreatmentList-classR Documentation

SimTreatmentList Class

Description

A class for treatment details as part of a simulation study. Objects of class SimTreatmentList should not be created directly but by the constructor sim_treatment_list().

Slots

treatment_list

named list of object of class Treatment, one object for each parameter variation.


psborrow2 documentation built on May 14, 2026, 5:10 p.m.