possible_data_sim_vars: Get All Variable Names in Simulated Data Model Matrix

View source: R/simulate_data_baseline.R

possible_data_sim_varsR Documentation

Get All Variable Names in Simulated Data Model Matrix

Description

Get All Variable Names in Simulated Data Model Matrix

Usage

possible_data_sim_vars(object)

Arguments

object

BaselineObject

Value

A vector of variable names


psborrow2 documentation built on May 14, 2026, 5:10 p.m.