| BorrowingFixedPowerPrior-class | R Documentation |
BorrowingFixedPowerPrior classBorrowingFixedPowerPrior class
method_namestring. The name of the method.
ext_flag_colcharacter. Name of the external flag column in the matrix.
powersnumeric. The fixed values to be used as the powers in the power prior.
Other borrowing classes:
Borrowing-class,
BorrowingFull-class,
BorrowingHierarchicalCommensurate-class,
BorrowingNone-class
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.